apps
==================================================
**Module**: :mod:`espressodb.base.utilities.apps`

.. currentmodule:: espressodb.base.utilities.apps

.. autosummary::
    get_project_apps
    get_app_name
    get_apps_slug_map

--------------

.. automodule:: espressodb.base.utilities.apps
    :members:
    :special-members:
